<?php
namespace App;

use DI\ContainerBuilder;
use Interop\Container\ContainerInterface;

use App\Util\Security as Security;

class App extends \DI\Bridge\Slim\App {

    protected function configureContainer(ContainerBuilder $builder)
    {
        $definitions = [
            'settings.displayErrorDetails' => true,

            \Doctrine\DBAL\Connection::class => function () {
                

                global $ENVIRONMENT_FILE;

                $environmentFile = $ENVIRONMENT_FILE;
                $environment     = json_decode($environmentFile, true);

                if(empty($environment)) {
                    throw new \Exception("environment not found!");
                }

                $connection = null;

                if($environment['driver'] == 'oci8') {
                    $dbPassword = $environment['password'];
                    if(isset($environment['encryptedPassword']) && $environment['encryptedPassword']) {
                        $dbPassword = Security::decrypt($environment['password']);
                    }
                    
                    global $CLIENT_DATA;
                    $envValue = getValueFromEnv("EXTERNAL_CLIENT_PRESET");
                    $CLIENT_DATA['client'] = empty($envValue) ? $environment['dbname'] : $envValue;

                    $connection = \Doctrine\DBAL\DriverManager::getConnection(array(
                        'user'        => $environment['user'],
                        'password'    => $dbPassword,
                        'host'        => $environment['host'],
                        'port'        => $environment['port'],
                        'dbname'      => $environment['dbname'],
                        'service'     => $environment['service'],
                        'driver'      => $environment['driver'],
                        'charset'     => $environment['charset'],
                        'sessionMode' => $environment["sessionMode"] === "OCI_CRED_EXT" ? OCI_CRED_EXT : OCI_DEFAULT
                    ), $config = new \Doctrine\DBAL\Configuration);
                } 

                //$sql = "ALTER SESSION SET CURRENT_SCHEMA = USR_ORG_4374";
                //$connection->executeQuery($sql);
                return $connection;
            }
        ];

        $builder->addDefinitions($definitions);
    }
}